@@ -23,44 +23,28 @@ Prompt String-like Print
 
 import os
 import sys
-from pathlib import Path
 
+from .config import read_config
 from .printer import PrintSpace
 
 
 # Initiate default print function
-def init_print(custom: str = None) -> PrintSpace:
+def init_print(custom: os.PathLike = None) -> PrintSpace:
     '''
     Initiate ps-print function with default marks
-    and marks read from various psprintrc configurarion files:
+    and marks read from various psprintrc configurarion files
 
     Args:
         custom: custom configuration file location
 
     '''
-    # psprintrc file locations
-    user_home = Path(os.environ["HOME"]).resolve()
-    config = os.environ.get("XDG_CONFIG_HOME", user_home.joinpath(".config"))
-    rc_locations = {
-        'root': Path("/etc/psprint/style.yml"),
-        'user': user_home.joinpath(".psprintrc"),  # bad
-        'config': Path(config).joinpath("psprint", "style.yml"),  # good
-        'local': Path(".psprintrc").resolve(),
-        'custom': Path(custom) if custom else None,
-    }
 
-    default_config = Path(__file__).parent.joinpath("style.yml")
-    default_print = PrintSpace(config=default_config)
-
-    for loc in ('root', 'user', 'config', 'local', 'custom'):
-        # DONT: loc from tuple, not keys(), deliberately to ascertain order
-        if rc_locations[loc] is not None:
-            if rc_locations[loc].is_file():  # type: ignore
-                default_print.set_opts(rc_locations[loc])
+    default_print = read_config(custom)
 
     if 'idlelib.run' in sys.modules or not sys.stdout.isatty():
         # Running inside idle
         default_print.switches['bland'] = True
+
     return default_print
 
 
@@ -85,4 +69,4 @@ ps formatting function for imports
 
 __all__ = ['DEFAULT_PRINT', 'print']
 
-__version__ = '1!1.1.0'
+__version__ = '1!1.2.0'
