@@ -82,6 +82,10 @@ class InfoMark():
                 text_args[key] = kwargs[f'text_{key}']
 
         # Determine prefixes
+        for p_type in 'pref', 'pref_s':
+            if kwargs.get(p_type) is not None:
+                if isinstance(kwargs[p_type], (int, float)):
+                    kwargs[p_type] = str(kwargs[p_type])
         pref = [kwargs.get('pref', ''), kwargs.get('pref_s', '>')]
         if pref[0] is not None and len(pref[0]) > pref_max:
             trim = pref[0][:pref_max]
