@@ -21,11 +21,9 @@
 Information- Prepended Print object
 '''
 
-import os
-import sys
-from typing import Dict, List, Optional, Union
-
-import yaml
+from sys import stdout
+from types import GeneratorType
+from typing import Dict, List, Optional, Tuple, Union
 
 from .ansi import ANSI
 from .errors import BadMark
@@ -33,15 +31,16 @@ from .mark_types import InfoMark
 
 
 class PrintSpace():
-    '''
+    """
     Fancy Print class that also prints the type of message
 
     Args:
-        config: path to default configuration file (shipped)
+        conf: parsed configuration
+        name: name of configuration file (to report errors)
 
     Attributes:
         pref_max: int: maximum length of prefix string
-        info_style; dict: pre-defined prefix styles
+        info_style; dict: pre-configured prefix styles
         info_index: list: keys of `info_style` mapped to int
         print_kwargs: dict : library of kwargs_accepted by print_function
         switches: dict: user-customizations: pad, short, bland, disabled
@@ -51,8 +50,11 @@ class PrintSpace():
             bland: bool: do not show ANSI color/styles for prefix/text
             disabled: bool: behave like python default print_function
 
-    '''
-    def __init__(self, config: os.PathLike) -> None:
+    """
+    def __init__(self,
+                 conf: Dict[str, dict] = None,
+                 /,
+                 name: str = None) -> None:
         # Standard info styles
         self.switches = {
             'pad': False,
@@ -61,7 +63,7 @@ class PrintSpace():
             'disabled': False
         }
         self.print_kwargs = {
-            'file': sys.stdout,
+            'file': stdout,
             'sep': "\t",
             'end': "\n",
             'flush': False
@@ -69,44 +71,83 @@ class PrintSpace():
         self.pref_max = None
         self.info_style: Dict[str, InfoMark] = {}
         self.info_index: List[str] = []
-        self.set_opts(config=config)
+        if conf is not None:
+            self.set_opts(conf, name or 'unnamed config file')
 
-    def set_opts(self, config: os.PathLike = None) -> None:
-        '''
-        Configure from rcfile
+    def __repr__(self) -> str:
+        """
+        Returns:
+            Formatted summary of info_style
+        """
+        outstr = '\npref\tlong\tshort\ttext\n\n'
+        outstr += "\n".join((f"{k}:{v}" for k, v in self.info_style.items()))
+        return outstr
+
+    def __contains__(self, mark: Union[str, InfoMark]) -> bool:
+        """
+        is mark defined?
+        """
+        if isinstance(mark, str):
+            return mark in self.info_style.keys()
+        return mark in self.info_style.values()
+
+    def __getitem__(self, mark: Union[int, str]) -> InfoMark:
+        """
+        Returns:
+            Infomark corresponding to mark
+        """
+        if isinstance(mark, str):
+            return self.info_style[mark]
+        if isinstance(mark, int):
+            if not 0 <= mark < len(self.info_index):
+                mark = 0
+            return self.info_style[self.info_index[mark]]
+        raise KeyError(mark)
+
+    def set_opts(self, conf: Dict[str, dict], /, name: str) -> None:
+        """
+        configuration from rcfile
 
         Args:
-            rcfile: .psprintrc file to read
+            conf: parsed configuration
+            name: name of configuration file (to report errors)
 
         Raises:
             BadMark
 
-        '''
-        if config is None:
+        """
+        if not conf:
             return
         info_index: Optional[Dict[str, str]] = None
-        with open(config, 'r') as rcfile:
-            conf: Dict[str, dict] = yaml.safe_load(rcfile)
         for mark, settings in conf.items():
             if mark == "FLAGS":
                 # switches / flags
-                self.pref_max = settings.get("pref_max_len", None)
-                for b_sw in self.switches:
-                    self.switches[b_sw] = settings.get(b_sw, False)
-                self.print_kwargs['sep'] = settings.get("sep", "\t")
-                self.print_kwargs['end'] = settings.get("end", "\n")
-                self.print_kwargs['flush'] = settings.get("flush", False)
+                self.pref_max = settings.get("pref_max", None)
+
+                # update psprint switches
+                self.switches.update(
+                    dict(
+                        filter(lambda x: x[0] in self.switches,
+                               settings.items())))
+
+                # update __builtin__,print kwargs
+                self.print_kwargs.update(
+                    dict(filter(lambda x: x[0] in self.print_kwargs,
+                                settings)))
+
+                # standard output file
                 fname = settings.get("file", None)  # Discouraged
                 if fname is not None:  # pragma: no cover
                     self.print_kwargs['file'] = open(fname, "a")
+
             elif mark == 'order':
                 info_index = settings
             else:
-                # Mark definition
+                # New mark definition
                 try:
                     self.edit_style(mark=mark, **settings)
-                except (ValueError, TypeError):
-                    raise BadMark(str(mark), rcfile.name) from None
+                except (ValueError, TypeError):  # pragma: no cover
+                    raise BadMark(str(mark), name) from None
         if info_index is not None:
             self.info_index = list(
                 filter(lambda x: x in self.info_style, info_index))
@@ -116,7 +157,7 @@ class PrintSpace():
                    index_int: int = None,
                    mark: str = None,
                    **kwargs) -> str:
-        '''
+        """
         Edit loaded style
 
         Args:
@@ -142,7 +183,7 @@ class PrintSpace():
         Returns
             Summary of new (updated) ``PrintSpace``
 
-        '''
+        """
         # correct pref
         if mark is None:
             mark = pref[:4]
@@ -156,7 +197,7 @@ class PrintSpace():
         return str(self)
 
     def remove_style(self, mark: str = None, index_int: int = None) -> str:
-        '''
+        """
         Args:
             mark: is popped out of defined styles
             index_int: is used to locate index_str if it is not provided
@@ -164,7 +205,7 @@ class PrintSpace():
         Returns
             Summary of new (updated) ``PrintSpace``
 
-        '''
+        """
         if mark is None:
             if index_int is not None:
                 if index_int < len(self.info_style):
@@ -176,19 +217,10 @@ class PrintSpace():
         del self.info_style[mark]
         return str(self)
 
-    def __repr__(self) -> str:
-        '''
-        Returns:
-            Formatted summary of info_style
-        '''
-        outstr = '\npref\tlong\tshort\ttext\n\n'
-        outstr += "\n".join((f"{k}:{v}" for k, v in self.info_style.items()))
-        return outstr
-
     def _which_mark(self,
                     mark: Union[str, int, InfoMark] = None,
                     **kwargs) -> InfoMark:
-        '''
+        """
         Define a mark based on arguments supplied
 
             * may be a pre-defined mark OR
@@ -213,21 +245,16 @@ class PrintSpace():
                     * text_gloss: gloss of text
                     * text_bgcol: background color of text
 
-        '''
+        """
         base_mark: InfoMark = self.info_style['cont']
         if mark is not None:
             # mark was supplied
             if isinstance(mark, InfoMark):
                 # ready-made mark was served
                 base_mark = mark
-            elif isinstance(mark, int):
+            elif isinstance(mark, (str, int)):
                 # mark supplied as index int
-                if not 0 <= mark < len(self.info_index):
-                    mark = 0
-                base_mark = self.info_style[self.info_index[mark]]
-            elif isinstance(mark, str):
-                # mark named key supplied
-                base_mark = self.info_style.get(mark) or base_mark
+                base_mark = self[mark]
             else:
                 raise BadMark(mark=str(mark), config="**kwargs")
         if any(arg in kwargs for arg in [
@@ -243,6 +270,26 @@ class PrintSpace():
             return InfoMark(parent=base_mark, pref_max=self.pref_max, **kwargs)
         return base_mark
 
+    def _iter_print(self,
+                    args,
+                    mark: Union[str, int, InfoMark] = None,
+                    **kwargs):
+        itertag = {
+            GeneratorType: 'generator:',
+            list: 'list:',
+            dict: 'dict:',
+            tuple: 'tuple:'
+        }
+        self.psprint(itertag[type(args)], mark=mark, **kwargs)
+        if isinstance(args, (list, tuple, GeneratorType)):
+            # make this more general
+            args = {index: value for index, value in enumerate(args)}
+        if 'pref' in kwargs:
+            del kwargs['pref']
+        kwargs['indent'] = kwargs.get('indent', 0) + 1
+        for key, value in args.items():
+            self.psprint(value, mark='list', pref=key, **kwargs)
+
     def psfmt(self,
               *args,
               mark: Union[str, int, InfoMark] = None,
@@ -253,7 +300,7 @@ class PrintSpace():
 
         Args:
             *args: passed to print_function for printing
-            mark: pre-declared `InfoMark` defaults:
+            mark: pre-configured `InfoMark` defaults:
 
                 * cont or 0 or anything else: nothing
                 * info or 1: [INFO]
@@ -307,7 +354,8 @@ class PrintSpace():
             for key in self.switches
         }
 
-        args_l = list(args)  # typecast
+        args_l = list('  ' * kwargs.get('indent', 0) + str(arg)
+                      for arg in args)  # typecast
         if switches['disabled'] or not args:
             if sep is not None:
                 return sep.join(args_l)
@@ -316,7 +364,7 @@ class PrintSpace():
         mark = self._which_mark(mark=mark, **kwargs)
 
         # add prefix to *args[0]
-        if not switches.get('bland'):
+        if not switches.get('bland'):  # pragma: no cover
             args_l[0] = str(mark.text) + str(args_l[0])
             args_l[-1] = str(args_l[-1]) + ANSI.RESET_ALL
         args_l[0] = mark.pref.to_str(**switches) + str(args_l[0])
@@ -331,9 +379,16 @@ class PrintSpace():
         """
         Prefix String PRINT
 
+        - Iterates through if the only argument supplied is
+
+          - ``GeneratorType``
+          - ``tuple``
+          - ``list``
+          - ``dict``
+
         Args:
             *args: passed to print_function for printing
-            mark: pre-declared `InfoMark` defaults:
+            mark: pre-configured `InfoMark` defaults:
 
                 * cont or 0 or anything else: nothing
                 * info or 1: [INFO]
@@ -345,7 +400,7 @@ class PrintSpace():
                 * `Other marks defined in .psprintrc`
 
             **kwargs:
-                * pref: str: prefix string long [length < 10 characters]
+                * pref: str: prefix string long [length < ``pref_max``]
                 * pref_s: str: prefix string short [1 character]
                 * code:
 
@@ -365,6 +420,7 @@ class PrintSpace():
                 * short: bool: display short, 1 character- prefix
                 * bland: bool: do not show ANSI color/styles for prefix/text
                 * disabled: bool: behave like python default print_function
+                * indent: indent level of print statement
                 * file: IO: passed to print function
                 * sep: str: passed to print function
                 * end: str: passed to print function
@@ -383,4 +439,8 @@ class PrintSpace():
             for key in self.print_kwargs
         }
 
-        print(*self.psfmt(*args, mark=mark, **kwargs), **print_kwargs)
+        if len(args) == 1 and isinstance(args[0],
+                                         (dict, GeneratorType, list, tuple)):
+            self._iter_print(args[0], mark=mark, **kwargs)
+        else:
+            print(*self.psfmt(*args, mark=mark, **kwargs), **print_kwargs)
